footing
########################################################################

Documentation
=============

`View the footing docs here
<https://footing.readthedocs.io/>`_.

Installation
============

Install footing with::

    pip3 install footing


Contributing Guide
==================

For information on setting up footing for development and
contributing changes, view `CONTRIBUTING.rst <CONTRIBUTING.rst>`_.
